@@ -1,20 +1,19 @@
 """Main functions for counting phrases."""
-from typing import Any, Optional
+from typing import Any
 
 from hashlib import sha256
-from pathlib import Path
 
 import pandas as pd
 from sklearn.feature_extraction.text import CountVectorizer
 
 from phrase_counter.cleaner import cleaner, fetch_page_text
 
-STOP_PATH = f"{Path(__file__).parent}/static/stop-words.txt"
-with open(STOP_PATH, "r", encoding="utf-8") as stop_file:
-    STOP_LIST = stop_file.readlines()
+# STOP_PATH = f"{Path(__file__).parent}/static/stop-words.txt"
+# with open(STOP_PATH, "r", encoding="utf-8") as stop_file:
+#     STOP_LIST = stop_file.readlines()
 
-# Removing newlines
-STOP_LIST = list(map(str.strip, STOP_LIST))
+# # Removing newlines
+# STOP_LIST = list(map(str.strip, STOP_LIST))
 
 
 def ingest_doc(
@@ -50,14 +49,12 @@ def ingest_doc(
     else:
         raise Exception("Unknown value for doc_type argument.")
 
-    cleaned_text = cleaner(dirty_text, replace_stop=replace_stop, stop_list=STOP_LIST)
-
-    # ----------------- Initialization -----------------
-    phrase_df = pd.DataFrame(columns=["bag", "count"])
+    cleaned_text = cleaner(dirty_text, replace_stop=replace_stop)
 
+    bags_list = []
+    counts_list = []
     # ----------------- Splitting -----------------
     for text_part in cleaned_text.split("."):
-
         # ----------------- Counter Section -----------------
         # Initializing vector
         count_vector = CountVectorizer(ngram_range=(1, 5), encoding="utf-8")
@@ -66,47 +63,20 @@ def ingest_doc(
             count_data = count_vector.fit_transform([text_part])
         except ValueError:
             continue
+        # ----------------- Extending data -----------------
+        bags_list.extend(count_vector.get_feature_names_out().tolist())
+        counts_list.extend(count_data.toarray()[0].tolist())
 
-        # ----------------- Dataframe creation -----------------
-        temp_df = pd.DataFrame(columns=["bag", "count"])
-        temp_df["bag"] = count_vector.get_feature_names_out().tolist()
-        temp_df["count"] = count_data.toarray()[0].tolist()
-
-        # Concating results
-        phrase_df = pd.concat([phrase_df, temp_df])
-
-    # Creating phrase hash
-    phrase_df["_key"] = phrase_df.apply(
-        lambda row: sha256(row["bag"].encode()).hexdigest(), axis=1
-    )
+    # Concating results
+    phrase_df = pd.DataFrame(zip(bags_list, counts_list), columns=["bag", "count"])
 
     # Aggregating for removing duplicate values (rows with same hash or phrase)
-    phrase_df = phrase_df.groupby(["bag", "_key"]).agg({"count": "sum"}).reset_index()
+    phrase_df = phrase_df.groupby(["bag"]).agg({"count": "sum"}).reset_index()
+
+    # Creating phrase hash
+    phrase_df["_key"] = [sha256(bag.encode()).hexdigest() for bag in phrase_df["bag"]]
 
-    # Changing status to suggested stop for phrases that conatin stop words
-    phrase_df["status"] = None
-    if tag_stop:
-        phrase_df["status"] = phrase_df.apply(
-            lambda row: stop_word_detector(row["bag"]), axis=1
-        )
     # Counting number of words in each bag
-    phrase_df["length"] = phrase_df.apply(
-        lambda row: len(str(row["bag"]).split()), axis=1
-    )
+    phrase_df["length"] = [len(str(bag).split()) for bag in phrase_df["bag"]]
+
     return phrase_df
-
-
-def stop_word_detector(phrase: str) -> Optional[str]:
-    """Find stop phrases based on existing list of stop words.
-
-    Args:
-        phrase: text of the phrase.
-
-    Returns:
-        status if stop words are in phrase.
-    """
-    # If there is any stop word in the phrase then it maybe a stop phrase
-    if any(stop_word in phrase.split() for stop_word in STOP_LIST):
-        return "suggested-stop"
-
-    return None
